==> haskell-rvar-0.3.0.2-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-1B7xwC7Wncc6avHwMpXy24
key:                  rvar-0.3.0.2-1B7xwC7Wncc6avHwMpXy24
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  c0b64701465cfad8da9a6f876be2ccf0
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-1B7xwC7Wncc6avHwMpXy24
depends:
    MonadPrompt-1.0.0.5-69ENdtsyMzNBnEHmyqW05t base-4.17.2.1
    bytestring-0.11.5.3 mtl-2.2.2 random-1.2.1.3-DyhQJBMZMiBKToaxsRw6jM
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rvar-0.3.0.2-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rvar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rvar
version:              0.3.0.2
visibility:           public
id:                   rvar-0.3.0.2-HuAkA7JQ4UJHHoUxCg6Cki
key:                  rvar-0.3.0.2-HuAkA7JQ4UJHHoUxCg6Cki
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            stable
homepage:             https://github.com/haskell-numerics/random-fu
synopsis:             Random Variables
description:
    Random number generation based on modeling random
    variables by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  23c54adfaffaab195451f1fdf64d6602
exposed:              True
exposed-modules:      Data.RVar
hidden-modules:       Data.RVar.Prim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rvar-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rvar
hs-libraries:         HSrvar-0.3.0.2-HuAkA7JQ4UJHHoUxCg6Cki
depends:
    MonadPrompt-1.0.0.5-69ENdtsyMzNBnEHmyqW05t base-4.17.2.1
    bytestring-0.11.5.3 mtl-2.2.2 random-1.2.1.3-6fLOERitWZgLekqeklTRBb
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-rvar/html/rvar.haddock
haddock-html:         /usr/share/doc/haskell-rvar/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
